branch: externals/idlwave
commit 91be96e6949bdd5d9c55c65bc58fa4e0856b234c
Author: JD Smith <[email protected]>
Commit: JD Smith <[email protected]>

    When no state is found during a scan, clear the highlight line.
---
 idlw-shell.el | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/idlw-shell.el b/idlw-shell.el
index 63efec4156..a7f82c3a32 100644
--- a/idlw-shell.el
+++ b/idlw-shell.el
@@ -1857,8 +1857,10 @@ the above."
                    idlwave-shell-command-output)
       (setq idlwave-shell-current-state 'breakpoint))
 
-     ;; Otherwise, no particular state
-     (t (setq idlwave-shell-current-state nil)))))
+     ;; Otherwise, no particular state, display no line
+     (t (setq idlwave-shell-current-state nil)
+       (unless idlwave-shell-post-command-hook
+         (idlwave-shell-display-line nil))))))
 
 
 (defun idlwave-shell-parse-line (string &optional skip-main)

Reply via email to